"""
Wyckoff positions for point groups (reduced coordinate).
    point-group tag: [ (Wyckoff letter, [representative position], default position) ]
"""
_data_wyckoff_pg = {
    "C1": [("1a", "{[x,y,z]}", "[0,0,0]")],
    "Ci": [("1o", "{[0,0,0]}", "[0,0,0]"), ("2a", "{[x,y,z],[-x,-y,-z]}", "[1,0,0]")],
    "C2": [("1a", "{[0,y,0]}", "[0,0,0]"), ("2b", "{[x,y,z],[-x,y,-z]}", "[1,0,0]")],
    "Cs": [("1a", "{[x,0,z]}", "[0,0,0]"), ("2b", "{[x,y,z],[x,-y,z]}", "[0,1,0]")],
    "C2h": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,y,0],[0,-y,0]}", "[0,1,0]"),
        ("2b", "{[x,0,z],[-x,0,-z]}", "[1,0,0]"),
        ("4c", "{[x,y,z],[-x,y,-z],[-x,-y,-z],[x,-y,z]}", "[1,1,0]"),
    ],
    "D2": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[x,0,0],[-x,0,0]}", "[1,0,0]"),
        ("2b", "{[0,y,0],[0,-y,0]}", "[0,1,0]"),
        ("2c", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("4d", "{[x,y,z],[-x,-y,z],[-x,y,-z],[x,-y,-z]}", "[1,1,0]"),
    ],
    "C2v": [
        ("1a", "{[0,0,z]}", "[0,0,0]"),
        ("2b", "{[x,0,z],[-x,0,z]}", "[1,0,0]"),
        ("2c", "{[0,y,z],[0,-y,z]}", "[0,1,0]"),
        ("4d", "{[x,y,z],[-x,-y,z],[x,-y,z],[-x,y,z]}", "[1,1,0]"),
    ],
    "D2h": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[x,0,0],[-x,0,0]}", "[1,0,0]"),
        ("2b", "{[0,y,0],[0,-y,0]}", "[0,1,0]"),
        ("2c", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("4d", "{[0,y,z],[0,-y,z],[0,y,-z],[0,-y,-z]}", "[0,1,1]"),
        ("4e", "{[x,0,z],[-x,0,z],[-x,0,-z],[x,0,-z]}", "[1,0,1]"),
        ("4f", "{[x,y,0],[-x,-y,0],[-x,y,0],[x,-y,0]}", "[1,1,0]"),
        ("8g", "{[x,y,z],[-x,-y,z],[-x,y,-z],[x,-y,-z],[-x,-y,-z],[x,y,-z],[x,-y,z],[-x,y,z]}", "[1,1,1]"),
    ],
    "C4": [("1a", "{[0,0,z]}", "[0,0,0]"), ("4b", "{[x,y,z],[-x,-y,z],[-y,x,z],[y,-x,z]}", "[1,0,0]")],
    "S4": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("4b", "{[x,y,z],[-x,-y,z],[y,-x,-z],[-y,x,-z]}", "[1,0,0]"),
    ],
    "C4h": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("4b", "{[x,y,0],[-x,-y,0],[-y,x,0],[y,-x,0]}", "[1,0,0]"),
        ("8c", "{[x,y,z],[-x,-y,z],[-y,x,z],[y,-x,z],[-x,-y,-z],[x,y,-z],[y,-x,-z],[-y,x,-z]}", "[1,1,1]"),
    ],
    "D4": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("4b", "{[x,x,0],[-x,-x,0],[x,-x,0],[-x,x,0]}", "[1,1,0]"),
        ("4c", "{[x,0,0],[-x,0,0],[0,x,0],[0,-x,0]}", "[1,0,0]"),
        ("8d", "{[x,y,z],[-x,-y,z],[x,-y,-z],[-x,y,-z],[y,x,-z],[-y,-x,-z],[-y,x,z],[y,-x,z]}", "[1,0,1]"),
    ],
    "C4v": [
        ("1a", "{[0,0,z]}", "[0,0,0]"),
        ("4b", "{[x,x,z],[-x,-x,z],[-x,x,z],[x,-x,z]}", "[1,1,0]"),
        ("4c", "{[x,0,z],[-x,0,z],[0,x,z],[0,-x,z]}", "[1,0,0]"),
        ("8d", "{[x,y,z],[-x,-y,z],[-y,x,z],[y,-x,z],[-x,y,z],[x,-y,z],[-y,-x,z],[y,x,z]}", "[2,1,0]"),
    ],
    "D2d": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("4b", "{[x,0,0],[-x,0,0],[0,-x,0],[0,x,0]}", "[1,0,0]"),
        ("4c", "{[x,x,z],[-x,-x,z],[x,-x,-z],[-x,x,-z]}", "[1,1,0]"),
        ("8d", "{[x,y,z],[-x,-y,z],[x,-y,-z],[-x,y,-z],[-y,-x,z],[y,x,z],[y,-x,-z],[-y,x,-z]}", "[2,1,0]"),
    ],
    "D2d-1": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("4b", "{[x,x,0],[-x,-x,0],[-x,x,0],[x,-x,0]}", "[1,1,0]"),
        ("4c", "{[x,0,z],[-x,0,z],[0,x,-z],[0,-x,-z]}", "[1,0,0]"),
        ("8d", "{[x,y,z],[-x,-y,z],[y,x,-z],[-y,-x,-z],[-x,y,z],[x,-y,z],[y,-x,-z],[-y,x,-z]}", "[2,1,0]"),
    ],
    "D4h": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("4b", "{[x,x,0],[-x,-x,0],[x,-x,0],[-x,x,0]}", "[1,1,0]"),
        ("4c", "{[x,0,0],[-x,0,0],[0,x,0],[0,-x,0]}", "[1,0,0]"),
        ("8d", "{[x,y,0],[-x,-y,0],[x,-y,0],[-x,y,0],[y,x,0],[-y,-x,0],[-y,x,0],[y,-x,0]}", "[2,1,0]"),
        ("8e", "{[x,x,z],[-x,-x,z],[x,-x,-z],[-x,x,-z],[x,x,-z],[-x,-x,-z],[-x,x,z],[x,-x,z]}", "[1,1,1]"),
        ("8f", "{[x,0,z],[-x,0,z],[x,0,-z],[-x,0,-z],[0,x,-z],[0,-x,-z],[0,x,z],[0,-x,z]}", "[1,0,1]"),
        (
            "16g",
            "{[x,y,z],[-x,-y,z],[x,-y,-z],[-x,y,-z],[y,x,-z],[-y,-x,-z],[-y,x,z],[y,-x,z],[-x,-y,-z],[x,y,-z],[-x,y,z],[x,-y,z],[-y,-x,z],[y,x,z],[y,-x,-z],[-y,x,-z]}",
            "[2,1,1]",
        ),
    ],
    "C3": [("1a", "{[0,0,z]}", "[0,0,0]"), ("3b", "{[x,y,z],[-y,x-y,z],[-x+y,-x,z]}", "[-1,-1,0]")],
    "C3i": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("6b", "{[x,y,z],[-y,x-y,z],[-x+y,-x,z],[-x,-y,-z],[y,-x+y,-z],[x-y,x,-z]}", "[-1,-1,0]"),
    ],
    "D3": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("3b", "{[x,2*x,0],[x,-x,0],[-2*x,-x,0]}", "[1,2,0]"),
        ("6c", "{[x,y,z],[-x+y,y,-z],[x,x-y,-z],[-y,-x,-z],[-y,x-y,z],[-x+y,-x,z]}", "[-1,-1,1]"),
    ],
    "D3-1": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("3b", "{[x,0,0],[-x,-x,0],[0,x,0]}", "[1,0,0]"),
        ("6c", "{[x,y,z],[x-y,-y,-z],[-x,-x+y,-z],[y,x,-z],[-y,x-y,z],[-x+y,-x,z]}", "[1,-1,1]"),
    ],
    "C3v": [
        ("1a", "{[0,0,z]}", "[0,0,0]"),
        ("3b", "{[x,2*x,z],[-2*x,-x,z],[x,-x,z]}", "[1,2,0]"),
        ("6c", "{[x,y,z],[-y,x-y,z],[-x+y,-x,z],[-x+y,y,z],[x,x-y,z],[-y,-x,z]}", "[-1,-1,0]"),
    ],
    "C3v-1": [
        ("1a", "{[0,0,z]}", "[0,0,0]"),
        ("3b", "{[x,0,z],[0,x,z],[-x,-x,z]}", "[1,0,0]"),
        ("6c", "{[x,y,z],[-y,x-y,z],[-x+y,-x,z],[x-y,-y,z],[-x,-x+y,z],[y,x,z]}", "[1,-1,0]"),
    ],
    "D3d": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("6b", "{[x,2*x,0],[x,-x,0],[-2*x,-x,0],[-x,-2*x,0],[-x,x,0],[2*x,x,0]}", "[1,2,0]"),
        ("6c", "{[x,0,z],[-x,0,-z],[x,x,-z],[0,-x,-z],[0,x,z],[-x,-x,z]}", "[1,0,0]"),
        (
            "12d",
            "{[x,y,z],[-x+y,y,-z],[x,x-y,-z],[-y,-x,-z],[-y,x-y,z],[-x+y,-x,z],[-x,-y,-z],[x-y,-y,z],[-x,-x+y,z],[y,x,z],[y,-x+y,-z],[x-y,x,-z]}",
            "[1,-1,1]",
        ),
    ],
    "D3d-1": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("6b", "{[x,0,0],[-x,-x,0],[0,x,0],[-x,0,0],[x,x,0],[0,-x,0]}", "[1,0,0]"),
        ("6c", "{[x,2*x,z],[-x,-2*x,-z],[-x,x,-z],[2*x,x,-z],[-2*x,-x,z],[x,-x,z]}", "[1,2,0]"),
        (
            "12d",
            "{[x,y,z],[x-y,-y,-z],[-x,-x+y,-z],[y,x,-z],[-y,x-y,z],[-x+y,-x,z],[-x,-y,-z],[-x+y,y,z],[x,x-y,z],[-y,-x,z],[y,-x+y,-z],[x-y,x,-z]}",
            "[-1,-1,1]",
        ),
    ],
    "C6": [
        ("1a", "{[0,0,z]}", "[0,0,0]"),
        ("6b", "{[x,y,z],[-x,-y,z],[-y,x-y,z],[-x+y,-x,z],[x-y,x,z],[y,-x+y,z]}", "[1,-1,0]"),
    ],
    "C3h": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("3b", "{[x,y,0],[-y,x-y,0],[-x+y,-x,0]}", "[1,0,0]"),
        ("6c", "{[x,y,z],[-y,x-y,z],[-x+y,-x,z],[x,y,-z],[-x+y,-x,-z],[-y,x-y,-z]}", "[-1,-1,1]"),
    ],
    "C6h": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("6b", "{[x,y,0],[-x,-y,0],[-y,x-y,0],[-x+y,-x,0],[x-y,x,0],[y,-x+y,0]}", "[1,0,0]"),
        (
            "12c",
            "{[x,y,z],[-x,-y,z],[-y,x-y,z],[-x+y,-x,z],[x-y,x,z],[y,-x+y,z],[-x,-y,-z],[x,y,-z],[y,-x+y,-z],[x-y,x,-z],[-x+y,-x,-z],[-y,x-y,-z]}",
            "[-1,-1,1]",
        ),
    ],
    "D6": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("6b", "{[x,0,0],[-x,0,0],[-x,-x,0],[0,x,0],[x,x,0],[0,-x,0]}", "[1,0,0]"),
        ("6c", "{[x,2*x,0],[-x,-2*x,0],[-x,x,0],[2*x,x,0],[x,-x,0],[-2*x,-x,0]}", "[1,2,0]"),
        (
            "12d",
            "{[x,y,z],[-x,-y,z],[x-y,-y,-z],[-x,-x+y,-z],[y,x,-z],[-x+y,y,-z],[x,x-y,-z],[-y,-x,-z],[-y,x-y,z],[-x+y,-x,z],[x-y,x,z],[y,-x+y,z]}",
            "[-1,-1,1]",
        ),
    ],
    "C6v": [
        ("1a", "{[0,0,z]}", "[0,0,0]"),
        ("6b", "{[x,0,z],[-x,0,z],[0,x,z],[-x,-x,z],[x,x,z],[0,-x,z]}", "[1,0,0]"),
        ("6c", "{[x,2*x,z],[-x,-2*x,z],[-2*x,-x,z],[x,-x,z],[-x,x,z],[2*x,x,z]}", "[1,2,0]"),
        (
            "12d",
            "{[x,y,z],[-x,-y,z],[-y,x-y,z],[-x+y,-x,z],[x-y,x,z],[y,-x+y,z],[-x+y,y,z],[x,x-y,z],[-y,-x,z],[x-y,-y,z],[-x,-x+y,z],[y,x,z]}",
            "[sqrt(3)+1,sqrt(3)-1,0]",
        ),
    ],
    "D3h": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("3b", "{[x,2*x,0],[x,-x,0],[-2*x,-x,0]}", "[1,2,0]"),
        ("6c", "{[x,2*x,z],[x,2*x,-z],[x,-x,-z],[-2*x,-x,-z],[-2*x,-x,z],[x,-x,z]}", "[1,2,1]"),
        ("6d", "{[x,y,0],[-x+y,y,0],[x,x-y,0],[-y,-x,0],[-y,x-y,0],[-x+y,-x,0]}", "[1,0,0]"),
        (
            "12e",
            "{[x,y,z],[-x+y,y,-z],[x,x-y,-z],[-y,-x,-z],[-y,x-y,z],[-x+y,-x,z],[-x+y,y,z],[x,x-y,z],[-y,-x,z],[x,y,-z],[-x+y,-x,-z],[-y,x-y,-z]}",
            "[-1,-1,1]",
        ),
    ],
    "D3h-1": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("3b", "{[x,0,0],[-x,-x,0],[0,x,0]}", "[1,0,0]"),
        ("6c", "{[x,0,z],[x,0,-z],[-x,-x,-z],[0,x,-z],[0,x,z],[-x,-x,z]}", "[1,0,1]"),
        ("6d", "{[x,y,0],[x-y,-y,0],[-x,-x+y,0],[y,x,0],[-y,x-y,0],[-x+y,-x,0]}", "[1,2,0]"),
        (
            "12e",
            "{[x,y,z],[x-y,-y,-z],[-x,-x+y,-z],[y,x,-z],[-y,x-y,z],[-x+y,-x,z],[x,y,-z],[x-y,-y,z],[-x,-x+y,z],[y,x,z],[-x+y,-x,-z],[-y,x-y,-z]}",
            "[1,-1,1]",
        ),
    ],
    "D6h": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("2a", "{[0,0,z],[0,0,-z]}", "[0,0,1]"),
        ("6b", "{[x,0,0],[-x,0,0],[-x,-x,0],[0,x,0],[x,x,0],[0,-x,0]}", "[1,0,0]"),
        ("6c", "{[x,2*x,0],[-x,-2*x,0],[-x,x,0],[2*x,x,0],[x,-x,0],[-2*x,-x,0]}", "[1,2,0]"),
        (
            "12d",
            "{[x,0,z],[-x,0,z],[x,0,-z],[-x,-x,-z],[0,x,-z],[-x,0,-z],[x,x,-z],[0,-x,-z],[0,x,z],[-x,-x,z],[x,x,z],[0,-x,z]}",
            "[1,0,1]",
        ),
        (
            "12e",
            "{[x,2*x,z],[-x,-2*x,z],[-x,-2*x,-z],[-x,x,-z],[2*x,x,-z],[x,2*x,-z],[x,-x,-z],[-2*x,-x,-z],[-2*x,-x,z],[x,-x,z],[-x,x,z],[2*x,x,z]}",
            "[1,2,1]",
        ),
        (
            "12f",
            "{[x,y,0],[-x,-y,0],[x-y,-y,0],[-x,-x+y,0],[y,x,0],[-x+y,y,0],[x,x-y,0],[-y,-x,0],[-y,x-y,0],[-x+y,-x,0],[x-y,x,0],[y,-x+y,0]}",
            "[sqrt(3)+1,sqrt(3)-1,0]",
        ),
        (
            "24g",
            "{[x,y,z],[-x,-y,z],[x-y,-y,-z],[-x,-x+y,-z],[y,x,-z],[-x+y,y,-z],[x,x-y,-z],[-y,-x,-z],[-y,x-y,z],[-x+y,-x,z],[x-y,x,z],[y,-x+y,z],[-x,-y,-z],[-x+y,y,z],[x,x-y,z],[-y,-x,z],[x,y,-z],[x-y,-y,z],[-x,-x+y,z],[y,x,z],[y,-x+y,-z],[x-y,x,-z],[-x+y,-x,-z],[-y,x-y,-z]}",
            "[sqrt(3)+1,sqrt(3)-1,1]",
        ),
    ],
    "T": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("4a", "{[x,x,x],[-x,-x,x],[x,-x,-x],[-x,x,-x]}", "[1,1,1]"),
        ("6b", "{[x,0,0],[-x,0,0],[0,x,0],[0,-x,0],[0,0,x],[0,0,-x]}", "[1,0,0]"),
        (
            "12c",
            "{[x,y,z],[-x,-y,z],[x,-y,-z],[-x,y,-z],[z,x,y],[-z,-x,y],[z,-x,-y],[-z,x,-y],[y,z,x],[-y,z,-x],[-y,-z,x],[y,-z,-x]}",
            "[1,1,0]",
        ),
    ],
    "Th": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("6a", "{[x,0,0],[-x,0,0],[0,x,0],[0,-x,0],[0,0,x],[0,0,-x]}", "[1,0,0]"),
        ("8b", "{[x,x,x],[-x,-x,x],[x,-x,-x],[-x,x,-x],[-x,-x,-x],[x,x,-x],[-x,x,x],[x,-x,x]}", "[1,1,1]"),
        (
            "12c",
            "{[0,y,z],[0,-y,z],[0,-y,-z],[0,y,-z],[z,0,y],[-z,0,y],[z,0,-y],[-z,0,-y],[y,z,0],[-y,z,0],[-y,-z,0],[y,-z,0]}",
            "[0,1,1]",
        ),
        (
            "24d",
            "{[x,y,z],[-x,-y,z],[x,-y,-z],[-x,y,-z],[z,x,y],[-z,-x,y],[z,-x,-y],[-z,x,-y],[y,z,x],[-y,z,-x],[-y,-z,x],[y,-z,-x],[-x,-y,-z],[x,y,-z],[-x,y,z],[x,-y,z],[-z,-x,-y],[z,x,-y],[-z,x,y],[z,-x,y],[-y,-z,-x],[y,-z,x],[y,z,-x],[-y,z,x]}",
            "[3,2,1]",
        ),
    ],
    "O": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("6a", "{[x,0,0],[-x,0,0],[0,x,0],[0,0,x],[0,-x,0],[0,0,-x]}", "[1,0,0]"),
        ("8b", "{[x,x,x],[-x,-x,x],[x,-x,-x],[-x,x,-x],[x,x,-x],[x,-x,x],[-x,x,x],[-x,-x,-x]}", "[1,1,1]"),
        (
            "12c",
            "{[0,y,y],[0,-y,y],[0,-y,-y],[0,y,-y],[y,0,-y],[y,-y,0],[-y,0,-y],[-y,-y,0],[y,0,y],[-y,0,y],[y,y,0],[-y,y,0]}",
            "[0,1,1]",
        ),
        (
            "24d",
            "{[x,y,z],[-x,-y,z],[x,-y,-z],[-x,y,-z],[y,x,-z],[z,-y,x],[-x,z,y],[-y,-x,-z],[-z,-y,-x],[-x,-z,-y],[z,x,y],[-z,-x,y],[z,-x,-y],[-z,x,-y],[y,z,x],[-y,z,-x],[-y,-z,x],[y,-z,-x],[-y,x,z],[x,-z,y],[z,y,-x],[y,-x,z],[x,z,-y],[-z,y,x]}",
            "[2,1,0]",
        ),
    ],
    "Td": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("4a", "{[x,x,x],[-x,-x,x],[x,-x,-x],[-x,x,-x]}", "[1,1,1]"),
        ("6b", "{[x,0,0],[-x,0,0],[0,x,0],[0,-x,0],[0,0,x],[0,0,-x]}", "[1,0,0]"),
        (
            "12c",
            "{[x,x,z],[-x,-x,z],[x,-x,-z],[-x,x,-z],[z,x,x],[-z,-x,x],[z,-x,-x],[-z,x,-x],[x,z,x],[-x,z,-x],[-x,-z,x],[x,-z,-x]}",
            "[1,1,0]",
        ),
        (
            "24d",
            "{[x,y,z],[-x,-y,z],[x,-y,-z],[-x,y,-z],[z,x,y],[-z,-x,y],[z,-x,-y],[-z,x,-y],[y,z,x],[-y,z,-x],[-y,-z,x],[y,-z,-x],[-y,-x,z],[-z,y,-x],[x,-z,-y],[y,x,z],[z,y,x],[x,z,y],[y,-x,-z],[-x,z,-y],[-z,-y,x],[-y,x,-z],[-x,-z,y],[z,-y,-x]}",
            "[2,1,0]",
        ),
    ],
    "Oh": [
        ("1o", "{[0,0,0]}", "[0,0,0]"),
        ("6a", "{[x,0,0],[-x,0,0],[0,x,0],[0,0,x],[0,-x,0],[0,0,-x]}", "[1,0,0]"),
        ("8b", "{[x,x,x],[-x,-x,x],[x,-x,-x],[-x,x,-x],[x,x,-x],[x,-x,x],[-x,x,x],[-x,-x,-x]}", "[1,1,1]"),
        (
            "12c",
            "{[0,y,y],[0,-y,y],[0,-y,-y],[0,y,-y],[y,0,-y],[y,-y,0],[-y,0,-y],[-y,-y,0],[y,0,y],[-y,0,y],[y,y,0],[-y,y,0]}",
            "[0,1,1]",
        ),
        (
            "24d",
            "{[0,y,z],[0,-y,z],[0,-y,-z],[0,y,-z],[y,0,-z],[z,-y,0],[0,z,y],[-y,0,-z],[-z,-y,0],[0,-z,-y],[z,0,y],[-z,0,y],[z,0,-y],[-z,0,-y],[y,z,0],[-y,z,0],[-y,-z,0],[y,-z,0],[-y,0,z],[0,-z,y],[z,y,0],[y,0,z],[0,z,-y],[-z,y,0]}",
            "[0,2,1]",
        ),
        (
            "24e",
            "{[x,x,z],[-x,-x,z],[x,-x,-z],[-x,x,-z],[x,x,-z],[z,-x,x],[-x,z,x],[-x,-x,-z],[-z,-x,-x],[-x,-z,-x],[z,x,x],[-z,-x,x],[z,-x,-x],[-z,x,-x],[x,z,x],[-x,z,-x],[-x,-z,x],[x,-z,-x],[-x,x,z],[x,-z,x],[z,x,-x],[x,-x,z],[x,z,-x],[-z,x,x]}",
            "[1,1,2]",
        ),
        (
            "48f",
            "{[x,y,z],[-x,-y,z],[x,-y,-z],[-x,y,-z],[y,x,-z],[z,-y,x],[-x,z,y],[-y,-x,-z],[-z,-y,-x],[-x,-z,-y],[z,x,y],[-z,-x,y],[z,-x,-y],[-z,x,-y],[y,z,x],[-y,z,-x],[-y,-z,x],[y,-z,-x],[-y,x,z],[x,-z,y],[z,y,-x],[y,-x,z],[x,z,-y],[-z,y,x],[-x,-y,-z],[x,y,-z],[-x,y,z],[x,-y,z],[-y,-x,z],[-z,y,-x],[x,-z,-y],[y,x,z],[z,y,x],[x,z,y],[-z,-x,-y],[z,x,-y],[-z,x,y],[z,-x,y],[-y,-z,-x],[y,-z,x],[y,z,-x],[-y,z,x],[y,-x,-z],[-x,z,-y],[-z,-y,x],[-y,x,-z],[-x,-z,y],[z,-y,-x]}",
            "[3,2,1]",
        ),
    ],
}
